@@ -47,6 +47,14 @@ class RestApiAccessor:
                   ):
         """
         Perform a POST request to url
+        :param url:
+        :param params:
+        :param headers:
+        :param verify:
+        :param cert:
+        :param timeout:
+        :param json_data:
+        :return: response object
         """
         response = self._session.post(
             url,
@@ -59,3 +67,34 @@ class RestApiAccessor:
         )
         response.raise_for_status()
         return response
+
+    def rest_put(self,
+                 url,
+                 params=None,
+                 headers=None,
+                 verify=True,
+                 cert=None,
+                 timeout=None,
+                 json_data=None,
+                 ):
+        """
+        Perform a PUT request to url
+        :param url:
+        :param params:
+        :param headers:
+        :param verify:
+        :param cert:
+        :param timeout:
+        :param json_data:
+        :return: response object
+        """
+        response = self._session.put(
+            url,
+            json=json_data,
+            params=params,
+            headers=headers,
+            verify=verify,
+            cert=cert,
+            timeout=timeout,
+        )
+        return response
